rhythmmakertools.TupletMonadRhythmMaker
=======================================

.. abjad-lineage:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker

.. autoclass:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.reverse
      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__call__
      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__eq__
      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__format__
      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__makenew__
      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__ne__
      ~abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__repr__

Bases
-----

- :py:class:`rhythmmakertools.RhythmMaker <abjad.tools.rhythmmakertools.RhythmMaker.RhythmMaker>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Methods
-------

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.reverse
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__call__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__eq__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__format__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__makenew__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__ne__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.TupletMonadRhythmMaker.TupletMonadRhythmMaker.__repr__
   :noindex:
